Learn R Programming

brxx (version 0.1.2)

brxx_Cor_general: brxx_Cor_general: Bayesian Estimation of Reliability from Correlation, General Form

Description

This function estimates reliability from correlation given the correlation estimate.

Usage

brxx_Cor_general(cor, alpha, beta, CI, items)

Arguments

cor

Correlation estimate.

alpha

Prior true score variance.

beta

Prior error variance.

CI

Credible interval quantile, as a decimal (ie, for 95 percent, 0.95).

items

Number of test items.

Value

Returns estimated median and quantile based credible limits for reliability.

Examples

Run this code
# NOT RUN {
brxx_Cor_general(cor=0.85,alpha=3.51,beta=1.75,CI=0.95,items=10)

# }

Run the code above in your browser using DataLab