powered by
This function estimates reliability from intraclass correlation given correlation.
brxx_ICC_general(WS, Resid, alpha, beta, CI, items)
Within subjects variance estimate.
Residual variance estimate.
Prior true score variance.
Prior error variance.
Credible interval quantile, as a decimal (ie, for 95 percent, 0.95).
Number of test items.
Returns estimated median and quantile based credible limits for reliability.
# NOT RUN { WS=20.4 Resid=3.6 alpha=3.51 beta=1.75 brxx_ICC_general(WS=WS,Resid=Resid,alpha=alpha,beta=beta,CI=0.95,items=5) # }
Run the code above in your browser using DataLab