powered by
This function estimates reliability from given true and error variance estimates.
brxx_general(a, b, alpha, beta, CI, items)
True score variance estimate.
Error variance estimate.
Prior true score variance.
Prior error variance.
Credible interval quantile, as a decimal (ie, for 95 percent, 0.95).
Number of test items.
Returns estimated median and quantile based credible limits for reliability.
# NOT RUN { a=18.7 b=3.3 alpha=3.51 beta=1.75 brxx_general(a=a,b=b,alpha=alpha,beta=beta,CI=0.95,items=10) # }
Run the code above in your browser using DataLab