powered by
This function estimates reliability from correlation given the correlation estimate.
brxx_Cor_general(cor, alpha, beta, CI, items)
Correlation estimate.
Prior true score variance.
Prior error variance.
Credible interval quantile, as a decimal (ie, for 95 percent, 0.95).
Number of test items.
Returns estimated median and quantile based credible limits for reliability.
# NOT RUN { brxx_Cor_general(cor=0.85,alpha=3.51,beta=1.75,CI=0.95,items=10) # }
Run the code above in your browser using DataLab